@@ -124,6 +124,9 @@ sub install ($self, $dst, @xlist) {
   Evo::Internal::Util::monkey_patch $dst, %patch;
 }
 
+no warnings 'once';
+*info = *symbols;
+
 1;
 
 __END__
@@ -138,7 +141,7 @@ Evo::Export::Meta
 
 =head1 VERSION
 
-version 0.0241
+version 0.0242
 
 =head1 AUTHOR
 
