@@ -1,6 +1,6 @@
 package Evo::Fs::Temp;
 use Evo 'File::Temp; File::Spec::Functions file_name_is_absolute';
-use Evo '-Class *, -new, new:_new';
+use Evo '-Class * -new new:_new';
 use Carp 'croak';
 
 with '-Fs';
@@ -48,7 +48,7 @@ Evo::Fs::Temp
 
 =head1 VERSION
 
-version 0.0241
+version 0.0242
 
 =head1 DESCRIPTION
 
